@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.1901';
+our $VERSION = '0.1902';
 
 use Math::Bezier;
 use MIDI::Simple ();
@@ -163,9 +163,9 @@ sub metronome38 {
     my $bars = shift || $self->bars;
 
     for ( 1 .. $bars ) {
-        $self->note( $self->eighth, $self->kick );
-        $self->note( $self->eighth);
-        $self->note( $self->eighth, $self->snare );
+        $self->note( $self->eighth, $self->closed_hh, $self->kick );
+        $self->note( $self->eighth, $self->closed_hh);
+        $self->note( $self->eighth, $self->closed_hh, $self->snare );
     }
 }
 
@@ -416,7 +416,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.1901
+version 0.1902
 
 =head1 SYNOPSIS
 
